searchNodes=[{"doc":"Dotenvy is an Elixir implementation of the original dotenv Ruby gem. It assists in setting environment variables in ways that are compatible with both mix releases and with runtime configuration using conventions that should be familiar to developers coming from other languages. Conveniences for reading the variables and converting thier values are included (See Dotenvy/env!/2 , Dotenvy.env/3 , and Dotenvy.Transformer.to/2 ). Unlike other configuration helpers, Dotenvy enforces no convention for the naming of your files: you may name your configuration files whatever you wish. .env and its variants is a common choice, but Dotenvy does not have opinions. You must only pass file paths as arguments to the Dotenvy.source/2 or Dotenvy.source!/2 functions. Usage Suggestion Dotenvy is designed to help help set up your application at runtime . However, saying &quot;at runtime&quot; isn't specific enough: an application's configuration must be bootstrapped before it can actually start. Although there are other places where Dotenvy may prove useful, it was designed with the config/runtime.exs in mind: that's where it helps make the hand-off from system environment variables to the application configuration in the cleanest, most declarative way possible. .env for environment-specific config It is possible to use only a config.exs and and runtime.exs file to configure many Elixir applications: let the .env files handle any differences between environments. Consider the following setup: config/config.exs # compile-time config import Config config :myapp , ecto_repos : [ MyApp.Repo ] config :myapp , MyApp.Repo , migration_timestamps : [ type : :utc_datetime , inserted_at : :created_at ] config/runtime.exs import Config import Dotenvy source ( [ &quot;.env&quot; , &quot;.env. \#{ config_env ( ) } &quot; ] ) config :myapp , MyApp.Repo , database : env! ( &quot;DATABASE&quot; , :string ) , username : env! ( &quot;USERNAME&quot; , :string ) , password : env! ( &quot;PASSWORD&quot; , :string ) , hostname : env! ( &quot;HOSTNAME&quot; , :string ) , pool_size : env! ( &quot;POOL_SIZE&quot; , :integer ) , adapter : env ( &quot;ADAPTER&quot; , :module , Ecto.Adapters.Postgres ) , pool : env! ( &quot;POOL&quot; , :module? ) .env DATABASE = myapp_dev USERNAME = myuser PASSWORD = mypassword HOSTNAME = localhost POOL_SIZE = 10 POOL = .env.test DATABASE = myapp_test USERNAME = myuser PASSWORD = mypassword HOSTNAME = localhost POOL_SIZE = 10 POOL = Ecto.Adapters.SQL.Sandbox The above setup would expect .env to be in the .gitignore . The above example demonstrates developer settings appropriate for local development, but a production deployment would only differ in its values : the shape of the file would be the same. The .env.test file is loaded when running tests, so its values override any of the values set in the .env . By using Dotenvy.env!/2 , there is a strong contract with the environment: the system running this app must have the designated environment variables set somehow, otherwise this app will not start (and a specific error will be raised). Using the nil-able variants of the type-casting (those ending with ? ) is an easy way to defer to default values: env!(&quot;POOL&quot;, :module?) requires that the POOL variable is set, but it will return a nil if the value is an empty string. See Dotenvy.Transformer for more details. Note for Mix Tasks If you have authored your own Mix tasks, you must ensure that they are loading application configuration in a way that is compatible with the runtime config. A good way to do this is to include Mix.Task.run(&quot;app.config&quot;) , e.g. def run ( _args ) do Mix.Task . run ( &quot;app.config&quot; ) # ... end","ref":"Dotenvy.html","title":"Dotenvy","type":"behaviour"},{"doc":"Attempts to read the given system environment variable ; if it exists, its value is converted to the given type . If the variable is not found, the provided default is returned. The default value will not be converted: it will be returned as-is. This allows greater control of the output. Although this relies on System.fetch_env/1 , it may still raise an error if an unsupported type is provided. Examples iex&gt; env ( &quot;PORT&quot; , :integer , 5432 ) 5433 iex&gt; env ( &quot;NOT_SET&quot; , :boolean , %{ not : &quot;converted&quot; } ) %{ not : &quot;converted&quot; }","ref":"Dotenvy.html#env/3","title":"Dotenvy.env/3","type":"function"},{"doc":"Reads the given system environment variable and converts its value to the given type . This relies on System.fetch_env!/1 so it will raise if a variable is not set. Examples iex&gt; env! ( &quot;PORT&quot; , :integer ) 5432 iex&gt; env! ( &quot;ENABLED&quot; , :boolean ) true","ref":"Dotenvy.html#env!/2","title":"Dotenvy.env!/2","type":"function"},{"doc":"A parser implementation should receive the contents read from a file, a map of vars (with string keys, as would come from System.get_env/0 ), and a keyword list of opts . This callback is provided to help facilitate testing. See Dotenvy.Parser for the default implementation.","ref":"Dotenvy.html#c:parse/3","title":"Dotenvy.parse/3","type":"callback"},{"doc":"Like Bash's source command, this loads the given file(s) and sets the corresponding system environment variables using a side effect function ( &amp;System.put_env/1 by default). Files are processed in the order they are given. Values parsed from one file may override values parsed from previous files: the last file parsed has final say. The :overwrite? option determines how the parsed values will be merged with the existing system values. Options :side_effect an arity 1 function called after the successful parsing of each of the given files. The default is &amp;System.put_env/1 , which will have the effect of setting system environment variables based on the results of the file parsing. :overwrite? boolean indicating whether or not values parsed from provided .env files should overwrite existing system environment variables. Default: false :parser module that parses the given file(s). Overridable for testing. Default: Dotenv.Parser :require_files specifies which of the given files (if any) must be present. When true , all the listed files must exist. When false , none of the listed files must exist. When some of the files are required and some are optional, provide a list specifying which files are required. :side_effect an arity 1 function called after the successful parsing of each of the given files. The default is &amp;System.put_env/1 , which will have the effect of setting system environment variables based on the results of the file parsing. :vars a map with string keys representing the starting pool of variables. Default: output of System.get_env/0 . Examples iex&gt; Dotenvy . source ( &quot;.env&quot; ) { :ok , %{ &quot;PWD&quot; =&gt; &quot;/users/home&quot; , &quot;DATABASE_URL&quot; =&gt; &quot;postgres://postgres:postgres@localhost/myapp&quot; , # ...etc... } } # If you only want to return the parsed contents of the listed files # ignoring system environment variables altogether iex&gt; Dotenvy . source ( [ &quot;file1&quot; , &quot;file2&quot; ] , side_effect : false , vars : %{ } )","ref":"Dotenvy.html#source/2","title":"Dotenvy.source/2","type":"function"},{"doc":"As source/2 , but returns map on success or raises on error.","ref":"Dotenvy.html#source!/2","title":"Dotenvy.source!/2","type":"function"},{"doc":"This module handles the parsing of the contents of .env files into maps with string keys. This implementation cleaves closely to the original dotenv package, but it is not a direct match (by design). See the docs for details on the supported file format. This implementation uses parsing over regular expressions for most of its work.","ref":"Dotenvy.Parser.html","title":"Dotenvy.Parser","type":"module"},{"doc":"Parse the given contents , substituting and merging with the given vars .","ref":"Dotenvy.Parser.html#parse/3","title":"Dotenvy.Parser.parse/3","type":"function"},{"doc":"Helps cast string values read from the System into values usable by the app. Remember: conversion is necessary because system ENV values are always strings.","ref":"Dotenvy.Transformer.html","title":"Dotenvy.Transformer","type":"module"},{"doc":"Converts strings into Elixir data types with support for nil-able values. Each type determines how to interpret the incoming string as well as how to interpret an empty string. E.g. when the type is :integer , an empty string is considered a 0 . Use a ? suffix when an empty string should be considered nil (a.k.a. a &quot;nullable&quot; value). Use a ! suffix when an empty string is not allowed. Use this when values are required. Types The following types are supported: :atom - converts to an atom. An empty string will be the atom :&quot;&quot; (!). :atom? - converts to an atom. An empty string will be considered nil :atom! - converts to an atom. An empty string will raise. :boolean - &quot;false&quot;, &quot;0&quot;, or an empty string &quot;&quot; will be considered boolean false . Any other non-empty value is considered true . :boolean? - as above, except an empty string will be considered nil :boolean! - as above, except an empty string will raise. :charlist - converts string to charlist. :charlist? - converts string to charlist. Empty string will be considered nil . :integer - converts a string to an integer. An empty string will be considered 0 . :integer? - as above, but an empty string will be considered nil . :integer! - as above, but an empty string will raise. :float - converts a string to an float. An empty string will be considered 0 . :float? - as above, but an empty string will be considered nil . :float! - as above, but an empty string will raise. :existing_atom - converts into an existing atom. Raises on error if the atom does not exist. :existing_atom? - as above, but an empty string will be considered nil . :existing_atom! - as above, but an empty string will raise. :module - converts a string into an Elixir module name. Raises on error. :module? - as above, but an empty string will be considered nil . :module! - as above, but an empty string will raise. :string - no conversion :string? - empty strings will be considered nil . :string! - as above, but an empty string will raise. Examples iex&gt; to ( &quot;debug&quot; , :atom ) :debug iex&gt; to ( &quot;&quot; , :boolean ) false iex&gt; to ( &quot;&quot; , :boolean? ) nil iex&gt; to ( &quot;5432&quot; , :integer ) 5432","ref":"Dotenvy.Transformer.html#to/2","title":"Dotenvy.Transformer.to/2","type":"function"},{"doc":"Dotenvy Dotenvy is an Elixir implementation of the original dotenv package, used for setting and reading configuration variables, compatible with mix and releases. Dotenv file format","ref":"readme.html","title":"Dotenvy","type":"extras"},{"doc":"Add dotenvy to your list of dependencies in mix.exs : def deps do [ { :dotenvy , &quot;~&gt; 0.1.0&quot; } ] end","ref":"readme.html#installation","title":"Dotenvy - Installation","type":"extras"},{"doc":"See the dotenvy module documentation for more info!","ref":"readme.html#usage","title":"Dotenvy - Usage","type":"extras"},{"doc":"&quot;dot&quot; by Stepan Voevodin from the Noun Project","ref":"readme.html#image-attribution","title":"Dotenvy - Image Attribution","type":"extras"},{"doc":"Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"Initial release.","ref":"changelog.html#v0-1-0","title":"Changelog - v0.1.0","type":"extras"},{"doc":"Dotenv File Format This implementation cleaves closely to the original dotenv package, but it is not a direct match (by design). Typically, a dotenv ( .env ) file is formatted into simple key-value pairs: S3_BUCKET = YOURS3BUCKET SECRET_KEY = YOURSECRETKEYGOESHERE You may add export in front of each line so you can source the file in bash (see Dotenvy.source/2 ): export S3_BUCKET = YOURS3BUCKET export SECRET_KEY = YOURSECRETKEYGOESHERE","ref":"dotenv-file-format.html","title":"Dotenv File Format","type":"extras"},{"doc":"For the sake of portability (and sanity), environment variable names must consist solely of letters, digits, and the &amp;gt;underscore&amp;lt; ( _ ) and must not begin with a digit. In regex-speak: [ a - zA - Z_ ] + [ a - zA - Z0 - 9 _ ] * Example variable names DATABASE_URL foobar NO - WORK # &lt;-- invalid !!! Ü BER # &lt;-- invalid !!! 2 MUCH # &lt;-- invalid !!!","ref":"dotenv-file-format.html#variable-names","title":"Dotenv File Format - Variable Names","type":"extras"},{"doc":"Values are what's to the right of the equals sign. They may be quoted. Using single quotes will prevent variables from being interpolated. SIMPLE = xyz123 INTERPOLATED = &quot;Multiple \\\\ nLines and variable substitution: ${SIMPLE}&quot; NON_INTERPOLATED = &#39;raw text without variable interpolation&#39; MULTILINE = &quot;&quot;&quot; long text here, e.g. a private SSH key &quot;&quot;&quot; Escape Sequences When wrapped in quotes, the following character strings will be interpreted (i.e. escaped) as specific codepoints in the same way you would expect if the values were assigned inside a script. \\n Linefeed (aka newline); -&gt; codepoint 10 \\r Carriage return; -&gt; codepoint 13 \\t Tab; -&gt; codepoint 9 \\f Form feed; -&gt; codepoint 12 \\b Backspace; -&gt; codepoint 92 \\&quot; Double-quote; -&gt; codepoint 34 \\' Single-quote; -&gt; codepoint 39 \\\\ Backslash; -&gt; codepoint 92 \\uFFFF Unicode escape (4 hex characters to denote the codepoint) If a backslash precedes any other character, that character will be interpretted literally: the backslash will essentially be ignored and removed from output. Interpolation (a.k.a. Variable Substitution) Values left unquoted or wrapped in double-quotes will interpolate variables that are in the the ${VAR} syntax. This can be useful to reference existing system ENV values or to reference values previously set in a parsed file. For example: USER = admin EMAIL = $ { USER } @example . org DATABASE_URL = &quot;postgres://${USER}@localhost/my_database&quot; CACHE_DIR = $ { PWD } / cache If a value must retain ${} in its output and should not be substituted with a value, wrap it in single quotes (see below). Multi-line values (e.g. private keys) can use the triple-quoted heredoc syntax: PRIVATE_KEY = &quot;&quot;&quot; -----BEGIN RSA PRIVATE KEY----- ... HkVN9... ... -----END DSA PRIVATE KEY----- &quot;&quot;&quot; Non-Interpolated If your values must retain ${} in their output, wrap the value in single quotes, e.g.: PASSWORD = &#39;!@ \\\\ nG0${k}k&#39; MESSAGE_TEMPLATE = &#39;&#39;&#39; Hello ${PERSON}, Nice to meet you! &#39;&#39;&#39;","ref":"dotenv-file-format.html#values","title":"Dotenv File Format - Values","type":"extras"},{"doc":"The hash-tag # symbol denotes comments, either on their own line or at the end of a line, but not inside quotes. # This is a comment SECRET_KEY = YOURSECRETKEYGOESHERE # also a comment SECRET_HASH = &quot;something-with-a-hash-#-this-is-not-a-comment&quot;","ref":"dotenv-file-format.html#comments","title":"Dotenv File Format - Comments","type":"extras"}]